package com.ruoyi.szxc.mapper;

import com.ruoyi.szxc.domain.SzxcJmInfo;
import org.apache.ibatis.annotations.MapKey;

import java.util.List;
import java.util.Map;

/**
 * 居民信息Mapper接口
 * 
 * @author hs
 * @date 2024-03-16
 */
public interface SzxcJmInfoMapper 
{
    /**
     * 查询居民信息
     * 
     * @param id 居民信息主键
     * @return 居民信息
     */
    public SzxcJmInfo selectSzxcJmInfoById(Long id);

    /**
     * 查询居民信息列表
     * 
     * @param szxcJmInfo 居民信息
     * @return 居民信息集合
     */
    public List<SzxcJmInfo> selectSzxcJmInfoList(SzxcJmInfo szxcJmInfo);

    /**
     * 新增居民信息
     * 
     * @param szxcJmInfo 居民信息
     * @return 结果
     */
    public int insertSzxcJmInfo(SzxcJmInfo szxcJmInfo);

    /**
     * 修改居民信息
     * 
     * @param szxcJmInfo 居民信息
     * @return 结果
     */
    public int updateSzxcJmInfo(SzxcJmInfo szxcJmInfo);

    /**
     * 删除居民信息
     * 
     * @param id 居民信息主键
     * @return 结果
     */
    public int deleteSzxcJmInfoById(Long id);

    /**
     * 批量删除居民信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSzxcJmInfoByIds(Long[] ids);

    @MapKey("")
    List<Map<String, Object>> getDataByAge();
    @MapKey("")
    List<Map<String, Object>> getDataBySex();
    @MapKey("")
    List<Map<String, Object>> getDataByTag();
}
